@@ -3,6 +3,7 @@
 #include "qprogressindicator.h"
 #include "ui_keygendialog.h"
 #include <QMessageBox>
+#include <QRegularExpression>
 
 #ifdef QT_DEBUG
 #include "debughelper.h"
@@ -83,9 +84,14 @@ void KeygenDialog::on_name_textChanged(const QString &arg1) {
 void KeygenDialog::replace(const QString &key, const QString &value) {
   QStringList clear;
   QString expert = ui->plainTextEdit->toPlainText();
-  QStringList lines = expert.split(QRegExp("[\r\n]"), QString::SkipEmptyParts);
-  foreach (QString line, lines) {
-    line.replace(QRegExp(key + ":.*"), key + ": " + value);
+  static const QRegularExpression newLines{"[\r\n]"};
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+  const QStringList lines = expert.split(newLines, Qt::SkipEmptyParts);
+#else
+  const QStringList lines = expert.split(newLines, QString::SkipEmptyParts);
+#endif
+  for (QString line : lines) {
+    line.replace(QRegularExpression(key + ":.*"), key + ": " + value);
     if (key == "Passphrase")
       line.replace("%no-protection", "Passphrase: " + value);
     clear.append(line);
@@ -101,8 +107,13 @@ void KeygenDialog::replace(const QString &key, const QString &value) {
 void KeygenDialog::no_protection(bool enable) {
   QStringList clear;
   QString expert = ui->plainTextEdit->toPlainText();
-  QStringList lines = expert.split(QRegExp("[\r\n]"), QString::SkipEmptyParts);
-  foreach (QString line, lines) {
+  static const QRegularExpression newLines{"[\r\n]"};
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+  const QStringList lines = expert.split(newLines, Qt::SkipEmptyParts);
+#else
+  const QStringList lines = expert.split(newLines, QString::SkipEmptyParts);
+#endif
+  for (QString line : lines) {
     bool remove = false;
     if (!enable) {
       if (line.indexOf("%no-protection") == 0)
@@ -132,10 +143,11 @@ void KeygenDialog::done(int r) {
     }
 
     // check email
-    QRegExp mailre(R"(\b[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}\b)");
-    mailre.setCaseSensitivity(Qt::CaseInsensitive);
-    mailre.setPatternSyntax(QRegExp::RegExp);
-    if (!mailre.exactMatch(ui->email->text())) {
+    static const QRegularExpression mailre(
+        QRegularExpression::anchoredPattern(
+            R"(\b[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}\b)"),
+        QRegularExpression::CaseInsensitiveOption);
+    if (!mailre.match(ui->email->text()).hasMatch()) {
       QMessageBox::critical(
           this, tr("Invalid email"),
           tr("The email address you typed is not a valid email address."));
