@@ -6,13 +6,12 @@
 
 #include "configdialog.h"
 #include "filecontent.h"
-#include "keygendialog.h"
 #include "passworddialog.h"
 #include "qpushbuttonasqrcode.h"
+#include "qpushbuttonshowpassword.h"
 #include "qpushbuttonwithclipboard.h"
 #include "qtpass.h"
 #include "qtpasssettings.h"
-#include "settingsconstants.h"
 #include "trayicon.h"
 #include "ui_mainwindow.h"
 #include "usersdialog.h"
@@ -47,7 +46,7 @@ MainWindow::MainWindow(const QString &searchText, QWidget *parent)
   m_qtPass = new QtPass(this);
 
   // register shortcut ctrl/cmd + Q to close the main window
-  new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this, SLOT(close()));
+  new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this, SLOT(close()));
   // register shortcut ctrl/cmd + C to copy the currently selected password
   new QShortcut(QKeySequence(QKeySequence::StandardKey::Copy), this,
                 SLOT(copyPasswordFromTreeview()));
@@ -86,6 +85,12 @@ MainWindow::MainWindow(const QString &searchText, QWidget *parent)
   connect(ui->treeView, &DeselectableTreeView::emptyClicked, this,
           &MainWindow::deselect);
 
+  if (QtPassSettings::isUseMonospace()) {
+    ui->textBrowser->setFont(QFont(QStringLiteral("Monospace")));
+  }
+  if (QtPassSettings::isNoLineWrapping()) {
+    ui->textBrowser->setLineWrapMode(QTextBrowser::NoWrap);
+  }
   ui->textBrowser->setOpenExternalLinks(true);
   ui->textBrowser->setContextMenuPolicy(Qt::CustomContextMenu);
   connect(ui->textBrowser, &QWidget::customContextMenuRequested, this,
@@ -107,13 +112,10 @@ MainWindow::MainWindow(const QString &searchText, QWidget *parent)
   initToolBarButtons();
   initStatusBar();
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
   ui->lineEdit->setClearButtonEnabled(true);
-#endif
 
   setUiElementsEnabled(true);
 
-  qsrand(static_cast<uint>(QTime::currentTime().msec()));
   QTimer::singleShot(10, this, SLOT(focusInput()));
 
   ui->lineEdit->setText(searchText);
@@ -238,6 +240,19 @@ void MainWindow::config() {
     d->wizard(); // does shit
   if (d->exec()) {
     if (d->result() == QDialog::Accepted) {
+      // Update the textBrowser font
+      if (QtPassSettings::isUseMonospace()) {
+        ui->textBrowser->setFont(QFont(QStringLiteral("Monospace")));
+      } else {
+        ui->textBrowser->setFont(QFont());
+      }
+      // Update the textBrowser line wrap mode
+      if (QtPassSettings::isNoLineWrapping()) {
+        ui->textBrowser->setLineWrapMode(QTextBrowser::NoWrap);
+      } else {
+        ui->textBrowser->setLineWrapMode(QTextBrowser::WidgetWidth);
+      }
+
       if (QtPassSettings::isAlwaysOnTop()) {
         Qt::WindowFlags flags = windowFlags();
         this->setWindowFlags(flags | Qt::WindowStaysOnTopHint);
@@ -305,7 +320,7 @@ QString MainWindow::getFile(const QModelIndex &index, bool forPass) {
   QString filePath = model.filePath(proxyModel.mapToSource(index));
   if (forPass) {
     filePath = QDir(QtPassSettings::getPassStore()).relativeFilePath(filePath);
-    filePath.replace(QRegExp("\\.gpg$"), "");
+    filePath.replace(Util::endsWithGpg(), "");
   }
   return filePath;
 }
@@ -355,8 +370,6 @@ void MainWindow::deselect() {
   ui->actionEdit->setEnabled(false);
   ui->actionDelete->setEnabled(false);
   ui->passwordName->setText("");
-  ui->actionDelete->setEnabled(false);
-  ui->actionEdit->setEnabled(false);
   clearPanel(false);
 }
 
@@ -386,7 +399,7 @@ void MainWindow::passShowHandler(const QString &p_output) {
   // show what is needed:
   if (QtPassSettings::isHideContent()) {
     output = "***" + tr("Content hidden") + "***";
-  } else {
+  } else if (!QtPassSettings::isDisplayAsIs()) {
     if (!password.isEmpty()) {
       // set the password, it is hidden if needed in addToGridLayout
       addToGridLayout(0, tr("Password"), password);
@@ -505,7 +518,10 @@ void MainWindow::onConfig() { config(); }
 void MainWindow::on_lineEdit_textChanged(const QString &arg1) {
   ui->statusBar->showMessage(tr("Looking for: %1").arg(arg1), 1000);
   ui->treeView->expandAll();
-
+  clearPanel(false);
+  ui->passwordName->setText("");
+  ui->actionEdit->setEnabled(false);
+  ui->actionDelete->setEnabled(false);
   searchTimer.start();
 }
 
@@ -516,12 +532,14 @@ void MainWindow::on_lineEdit_textChanged(const QString &arg1) {
 void MainWindow::onTimeoutSearch() {
   QString query = ui->lineEdit->text();
 
-  if (query.isEmpty())
+  if (query.isEmpty()) {
     ui->treeView->collapseAll();
+    deselect();
+  }
 
-  query.replace(QRegExp(" "), ".*");
-  QRegExp regExp(query, Qt::CaseInsensitive);
-  proxyModel.setFilterRegExp(regExp);
+  query.replace(QStringLiteral(" "), ".*");
+  QRegularExpression regExp(query, QRegularExpression::CaseInsensitiveOption);
+  proxyModel.setFilterRegularExpression(regExp);
   ui->treeView->setRootIndex(proxyModel.mapFromSource(
       model.setRootPath(QtPassSettings::getPassStore())));
 
@@ -617,6 +635,14 @@ void MainWindow::addPassword() {
  * sure.
  */
 void MainWindow::onDelete() {
+  QModelIndex currentIndex = ui->treeView->currentIndex();
+  if (!currentIndex.isValid()) {
+    // This fixes https://github.com/IJHack/QtPass/issues/556
+    // Otherwise the entire password directory would be deleted if
+    // nothing is selected in the tree view.
+    return;
+  }
+
   QFileInfo fileOrFolder =
       model.fileInfo(proxyModel.mapToSource(ui->treeView->currentIndex()));
   QString file = "";
@@ -649,9 +675,8 @@ void MainWindow::onDelete() {
 
   if (QMessageBox::question(
           this, isDir ? tr("Delete folder?") : tr("Delete password?"),
-          tr("Are you sure you want to delete %1%2")
-              .arg(QDir::separator() + file)
-              .arg(isDir ? dirMessage : "?"),
+          tr("Are you sure you want to delete %1%2?")
+              .arg(QDir::separator() + file, isDir ? dirMessage : "?"),
           QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes)
     return;
 
@@ -735,7 +760,8 @@ void MainWindow::generateKeyPair(QString batch, QDialog *keygenWindow) {
  * select a more appropriate one to view too
  */
 void MainWindow::updateProfileBox() {
-  QHash<QString, QString> profiles = QtPassSettings::getProfiles();
+  QHash<QString, QHash<QString, QString>> profiles =
+      QtPassSettings::getProfiles();
 
   if (profiles.isEmpty()) {
     ui->profileWidget->hide();
@@ -743,7 +769,7 @@ void MainWindow::updateProfileBox() {
     ui->profileWidget->show();
     ui->profileBox->setEnabled(profiles.size() > 1);
     ui->profileBox->clear();
-    QHashIterator<QString, QString> i(profiles);
+    QHashIterator<QString, QHash<QString, QString>> i(profiles);
     while (i.hasNext()) {
       i.next();
       if (!i.key().isEmpty())
@@ -764,9 +790,15 @@ void MainWindow::updateProfileBox() {
 void MainWindow::on_profileBox_currentIndexChanged(QString name) {
   if (m_qtPass->isFreshStart() || name == QtPassSettings::getProfile())
     return;
+
+  ui->lineEdit->clear();
+
   QtPassSettings::setProfile(name);
 
-  QtPassSettings::setPassStore(QtPassSettings::getProfiles()[name]);
+  QtPassSettings::setPassStore(
+      QtPassSettings::getProfiles().value(name).value("path"));
+  QtPassSettings::setPassSigningKey(
+      QtPassSettings::getProfiles().value(name).value("signingKey"));
   ui->statusBar->showMessage(tr("Profile changed to %1").arg(name), 2000);
 
   QtPassSettings::getPass()->updateEnv();
@@ -940,6 +972,7 @@ void MainWindow::showBrowserContextMenu(const QPoint &pos) {
   QPoint globalPos = ui->textBrowser->viewport()->mapToGlobal(pos);
 
   contextMenu->exec(globalPos);
+  delete contextMenu;
 }
 
 /**
@@ -1010,15 +1043,17 @@ void MainWindow::editPassword(const QString &file) {
 void MainWindow::renamePassword() {
   bool ok;
   QString file = getFile(ui->treeView->currentIndex(), false);
-  QString fileName = QFileInfo(file).baseName();
+  QString filePath = QFileInfo(file).path();
+  QString fileName = QFileInfo(file).fileName();
+  if (fileName.endsWith(".gpg", Qt::CaseInsensitive))
+    fileName.chop(4);
+
   QString newName =
       QInputDialog::getText(this, tr("Rename file"), tr("Rename File To: "),
                             QLineEdit::Normal, fileName, &ok);
   if (!ok || newName.isEmpty())
     return;
-  QString newFile = file;
-  newFile.replace(file.lastIndexOf(fileName), fileName.length(), newName);
-  newFile.replace(QRegExp("\\.gpg$"), "");
+  QString newFile = QDir(filePath).filePath(newName);
   QtPassSettings::getPass()->Move(file, newFile);
 }
 
@@ -1067,14 +1102,15 @@ void MainWindow::addToGridLayout(int position, const QString &field,
   QFrame *frame = new QFrame();
   QLayout *ly = new QHBoxLayout();
   ly->setContentsMargins(5, 2, 2, 2);
+  ly->setSpacing(0);
   frame->setLayout(ly);
   if (QtPassSettings::getClipBoardType() != Enums::CLIPBOARD_NEVER) {
     auto *fieldLabel = new QPushButtonWithClipboard(trimmedValue, this);
     connect(fieldLabel, &QPushButtonWithClipboard::clicked, m_qtPass,
             &QtPass::copyTextToClipboard);
 
-    fieldLabel->setStyleSheet("border-style: none ; background: transparent;");
-    // fieldLabel->setContentsMargins(0,5,5,0);
+    fieldLabel->setStyleSheet(
+        "border-style: none ; background: transparent; padding: 0; margin: 0;");
     frame->layout()->addWidget(fieldLabel);
   }
 
@@ -1082,20 +1118,33 @@ void MainWindow::addToGridLayout(int position, const QString &field,
     QPushButtonAsQRCode *qrbutton = new QPushButtonAsQRCode(trimmedValue, this);
     connect(qrbutton, &QPushButtonAsQRCode::clicked, m_qtPass,
             &QtPass::showTextAsQRCode);
-    qrbutton->setStyleSheet("border-style: none ; background: transparent;");
-
+    qrbutton->setStyleSheet(
+        "border-style: none ; background: transparent; padding: 0; margin: 0;");
     frame->layout()->addWidget(qrbutton);
   }
 
   // set the echo mode to password, if the field is "password"
+  const QString lineStyle =
+      QtPassSettings::isUseMonospace()
+          ? "border-style: none; background: transparent; font-family: "
+            "monospace;"
+          : "border-style: none; background: transparent;";
+
   if (QtPassSettings::isHidePassword() && trimmedField == tr("Password")) {
+
     auto *line = new QLineEdit();
     line->setObjectName(trimmedField);
     line->setText(trimmedValue);
     line->setReadOnly(true);
-    line->setStyleSheet("border-style: none ; background: transparent;");
+    line->setStyleSheet(lineStyle);
     line->setContentsMargins(0, 0, 0, 0);
     line->setEchoMode(QLineEdit::Password);
+    QPushButtonShowPassword *showButton =
+        new QPushButtonShowPassword(line, this);
+    showButton->setStyleSheet(
+        "border-style: none ; background: transparent; padding: 0; margin: 0;");
+    showButton->setContentsMargins(0, 0, 0, 0);
+    frame->layout()->addWidget(showButton);
     frame->layout()->addWidget(line);
   } else {
     auto *line = new QTextBrowser();
@@ -1106,12 +1155,10 @@ void MainWindow::addToGridLayout(int position, const QString &field,
     line->setSizePolicy(
         QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
     line->setObjectName(trimmedField);
-    trimmedValue.replace(
-        QRegExp("((?:https?|ftp|ssh|sftp|ftps|webdav|webdavs)://\\S+)"),
-        R"(<a href="\1">\1</a>)");
+    trimmedValue.replace(Util::protocolRegex(), R"(<a href="\1">\1</a>)");
     line->setText(trimmedValue);
     line->setReadOnly(true);
-    line->setStyleSheet("border-style: none ; background: transparent;");
+    line->setStyleSheet(lineStyle);
     line->setContentsMargins(0, 0, 0, 0);
     frame->layout()->addWidget(line);
   }
