@@ -2,18 +2,18 @@
 #define QPUSHBUTTONWITHCLIPBOARD_H_
 
 #include <QPushButton>
-#include <QWidget>
 
 /*!
     \class QPushButtonWithClipboard
     \brief Stylish widget to allow copying of password and account details
 */
+class QWidget;
 class QPushButtonWithClipboard : public QPushButton {
   Q_OBJECT
 
 public:
   explicit QPushButtonWithClipboard(const QString &textToCopy = "",
-                                    QWidget *parent = 0);
+                                    QWidget *parent = nullptr);
 
   QString getTextToCopy() const;
   void setTextToCopy(const QString &value);
