@@ -8,7 +8,7 @@
     \brief Wrapper for executing pass to handle the password-store
 */
 class RealPass : public Pass {
-  void executePass(PROCESS id, const QStringList &arg,
+  void executePass(PROCESS id, const QStringList &args,
                    QString input = QString(), bool readStdout = true,
                    bool readStderr = true);
 
@@ -21,7 +21,7 @@ public:
   virtual void GitPush() Q_DECL_OVERRIDE;
   virtual void Show(QString file) Q_DECL_OVERRIDE;
   virtual void OtpGenerate(QString file) Q_DECL_OVERRIDE;
-  virtual void Insert(QString file, QString value,
+  virtual void Insert(QString file, QString newValue,
                       bool overwrite = false) Q_DECL_OVERRIDE;
   virtual void Remove(QString file, bool isDir = false) Q_DECL_OVERRIDE;
   virtual void Init(QString path, const QList<UserInfo> &users) Q_DECL_OVERRIDE;
