@@ -1,9 +1,12 @@
 #include "storemodel.h"
 #include "qtpasssettings.h"
 
+#include "util.h"
 #include <QDebug>
+#include <QFileSystemModel>
 #include <QMessageBox>
 #include <QMimeData>
+#include <QRegularExpression>
 #include <utility>
 
 QDataStream &
@@ -67,8 +70,8 @@ bool StoreModel::ShowThis(const QModelIndex index) const {
     QModelIndex useIndex = sourceModel()->index(index.row(), 0, index.parent());
     QString path = fs->filePath(useIndex);
     path = QDir(store).relativeFilePath(path);
-    path.replace(QRegExp("\\.gpg$"), "");
-    retVal = path.contains(filterRegExp());
+    path.replace(Util::endsWithGpg(), "");
+    retVal = path.contains(filterRegularExpression());
   }
   return retVal;
 }
@@ -100,7 +103,7 @@ QVariant StoreModel::data(const QModelIndex &index, int role) const {
 
   if (role == Qt::DisplayRole) {
     QString name = initial_value.toString();
-    name.replace(QRegExp("\\.gpg$"), "");
+    name.replace(Util::endsWithGpg(), "");
     initial_value.setValue(name);
   }
 
@@ -114,6 +117,7 @@ QVariant StoreModel::data(const QModelIndex &index, int role) const {
 Qt::DropActions StoreModel::supportedDropActions() const {
   return Qt::CopyAction | Qt::MoveAction;
 }
+
 /**
  * @brief StoreModel::supportedDragActions enable drag.
  * @return
@@ -122,6 +126,11 @@ Qt::DropActions StoreModel::supportedDragActions() const {
   return Qt::CopyAction | Qt::MoveAction;
 }
 
+/**
+ * @brief StoreModel::flags
+ * @param index
+ * @return
+ */
 Qt::ItemFlags StoreModel::flags(const QModelIndex &index) const {
   Qt::ItemFlags defaultFlags = QSortFilterProxyModel::flags(index);
 
@@ -131,12 +140,21 @@ Qt::ItemFlags StoreModel::flags(const QModelIndex &index) const {
   return Qt::ItemIsDropEnabled | defaultFlags;
 }
 
+/**
+ * @brief StoreModel::mimeTypes
+ * @return
+ */
 QStringList StoreModel::mimeTypes() const {
   QStringList types;
   types << "application/vnd+qtpass.dragAndDropInfoPasswordStore";
   return types;
 }
 
+/**
+ * @brief StoreModel::mimeData
+ * @param indexes
+ * @return
+ */
 QMimeData *StoreModel::mimeData(const QModelIndexList &indexes) const {
   dragAndDropInfoPasswordStore info;
 
@@ -159,6 +177,15 @@ QMimeData *StoreModel::mimeData(const QModelIndexList &indexes) const {
   return mimeData;
 }
 
+/**
+ * @brief StoreModel::canDropMimeData
+ * @param data
+ * @param action
+ * @param row
+ * @param column
+ * @param parent
+ * @return
+ */
 bool StoreModel::canDropMimeData(const QMimeData *data, Qt::DropAction action,
                                  int row, int column,
                                  const QModelIndex &parent) const {
@@ -199,6 +226,15 @@ bool StoreModel::canDropMimeData(const QMimeData *data, Qt::DropAction action,
   return false;
 }
 
+/**
+ * @brief StoreModel::dropMimeData
+ * @param data
+ * @param action
+ * @param row
+ * @param column
+ * @param parent
+ * @return
+ */
 bool StoreModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
                               int row, int column, const QModelIndex &parent) {
   if (!canDropMimeData(data, action, row, column, parent))
@@ -217,11 +253,9 @@ bool StoreModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
       this->index(parent.row(), parent.column(), parent.parent());
   QFileInfo destFileinfo = fs->fileInfo(mapToSource(destIndex));
   QFileInfo srcFileInfo = QFileInfo(info.path);
-  QDir qdir;
   QString cleanedSrc = QDir::cleanPath(srcFileInfo.absoluteFilePath());
   QString cleanedDest = QDir::cleanPath(destFileinfo.absoluteFilePath());
   if (info.isDir) {
-    QDir srcDir = QDir(info.path);
     // dropped dir onto dir
     if (destFileinfo.isDir()) {
       QDir destDir = QDir(cleanedDest).filePath(srcFileInfo.fileName());
@@ -244,7 +278,7 @@ bool StoreModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
       // dropped file onto a file
       int answer = QMessageBox::question(
           nullptr, tr("force overwrite?"),
-          tr("overwrite %1 with %2?").arg(cleanedDest).arg(cleanedSrc),
+          tr("overwrite %1 with %2?").arg(cleanedDest, cleanedSrc),
           QMessageBox::Yes | QMessageBox::No);
       bool force = answer == QMessageBox::Yes;
       if (action == Qt::MoveAction) {
@@ -257,6 +291,12 @@ bool StoreModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
   return true;
 }
 
+/**
+ * @brief StoreModel::lessThan
+ * @param source_left
+ * @param source_right
+ * @return
+ */
 bool StoreModel::lessThan(const QModelIndex &source_left,
                           const QModelIndex &source_right) const {
 /* matches logic in QFileSystemModelSorter::compareNodes() */
